netapp_ontap.models.cluster_nodes_controller API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cluster_nodes_controller`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ClusterNodesControllerSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterNodesController object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `board: str GET`

    Type of the system board. This is defined by vendor.

    Example: System Board XXVIII

  `cpu: ClusterNodesControllerCpu GET POST PATCH`

    CPU information.

  `failed_fan: ClusterNodesControllerFailedFan GET POST PATCH`

    The failed_fan field of the cluster_nodes_controller.

  `failed_power_supply: ClusterNodesControllerFailedPowerSupply GET POST PATCH`

    The failed_power_supply field of the cluster_nodes_controller.

  `flash_cache: List[ClusterNodesControllerFlashCache] GET`

    A list of Flash-Cache devices. Only returned when requested by name.

  `frus: List[ClusterNodesControllerFrus] GET POST PATCH`

    List of FRUs on the node. Only returned when requested by name.

  `memory_size: Size GET`

    Memory available on the node, in bytes.

    Example: 1024000000

  `over_temperature: str GET`

    Specifies whether the hardware is currently operating outside of its recommended temperature range. The hardware shuts down if the temperature exceeds critical thresholds.

    Valid choices:

    - over
    - normal